@@ -1,9 +1,7 @@
 from applitools.common import (
     BatchInfo,
     MatchLevel,
-    Region,
     logger,
-    RectangleSize,
     TestResults,
     TestResultContainer,
     TestResultsSummary,
@@ -11,12 +9,21 @@ from applitools.common import (
     StdoutLogger,
     FileLogger,
 )
+from applitools.common.geometry import AccessibilityRegion, RectangleSize, Region
+from applitools.common.accessibility import (
+    AccessibilityRegionType,
+    AccessibilityLevel,
+    AccessibilitySettings,
+    AccessibilityGuidelinesVersion,
+)
+from applitools.core.fluent.region import AccessibilityRegionByRectangle
 from applitools.core.cut import (
     FixedCutProvider,
     NullCutProvider,
     UnscaledFixedCutProvider,
 )
 from applitools.core.batch_close import BatchClose
+
 from applitools.images.fluent import Target
 
 from .eyes import Eyes
@@ -39,4 +46,10 @@ __all__ = (
     "TestResultsSummary",
     "BatchClose",
     "Configuration",
+    "AccessibilityRegionType",
+    "AccessibilityLevel",
+    "AccessibilitySettings",
+    "AccessibilityGuidelinesVersion",
+    "AccessibilityRegionByRectangle",
+    "AccessibilityRegion",
 )
